summaryrefslogtreecommitdiffstats
path: root/ash/screen_ash.h
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-07-18 16:40:06 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-07-18 16:40:06 +0000
commit8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80 (patch)
tree4fd429027e6fe44e79e8395ae63d6542d7edf657 /ash/screen_ash.h
parent87cc09add3a1a9ef94aaec1865fc3aaa23720aaa (diff)
downloadchromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.zip
chromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.tar.gz
chromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.tar.bz2
* Use Virtual Screen Coordinates in more places
- When setting widget bounds. - Workspace Manager - When resizing - Restore bounds * Refactored ScreenPositionClient to manage Screen coordinates for different configurations. * Renamed GetBounds/SetBounds methods to GetScreen/ParentBounds to make it clear that in which coordinates you're dealing with. * I used InScreen/InParent for RestoreBounds because RestoreParent/ScreenBounds sounds strange. Converted Linux/Aura to use ScreenPositionClient. BUG=123160 TEST=several tests are updated to match VSC. added screen_ash_unittests. I'll update rest of tests when this is enable by default. Review URL: https://chromiumcodereview.appspot.com/10696023 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@147250 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/screen_ash.h')
-rw-r--r--ash/screen_ash.h27
1 files changed, 22 insertions, 5 deletions
diff --git a/ash/screen_ash.h b/ash/screen_ash.h
index dae6da6..94fb54b 100644
--- a/ash/screen_ash.h
+++ b/ash/screen_ash.h
@@ -20,12 +20,29 @@ class ASH_EXPORT ScreenAsh : public gfx::ScreenImpl {
ScreenAsh();
virtual ~ScreenAsh();
- // Returns the bounds for maximized windows. Maximized windows trigger
- // auto-hiding the shelf.
- static gfx::Rect GetMaximizedWindowBounds(aura::Window* window);
+ // Returns the bounds for maximized windows in parent coordinates.
+ // Maximized windows trigger auto-hiding the shelf.
+ static gfx::Rect GetMaximizedWindowParentBounds(aura::Window* window);
- // Returns work area when a maximized window is not present.
- static gfx::Rect GetUnmaximizedWorkAreaBounds(aura::Window* window);
+ // Returns work area when a maximized window is not present in
+ // parent coordinates.
+ static gfx::Rect GetUnmaximizedWorkAreaParentBounds(aura::Window* window);
+
+ // Returns the display bounds in parent coordinates.
+ static gfx::Rect GetDisplayParentBounds(aura::Window* window);
+
+ // Returns the display's work area bounds in parent coordinates.
+ static gfx::Rect GetDisplayWorkAreaParentBounds(aura::Window* window);
+
+ // Converts |rect| from |window|'s coordinates to the virtual screen
+ // coordinates.
+ static gfx::Rect ConvertRectToScreen(aura::Window* window,
+ const gfx::Rect& rect);
+
+ // Converts |rect| from virtual screen coordinates to the |window|'s
+ // coordinates.
+ static gfx::Rect ConvertRectFromScreen(aura::Window* window,
+ const gfx::Rect& rect);
protected:
virtual gfx::Point GetCursorScreenPoint() OVERRIDE;